@@ -1,5 +1,5 @@
 """Commands module."""
-from typing import Dict, List, Type
+from typing import Dict, Type
 
 from .advanced_mode import GetAdvancedMode, SetAdvancedMode
 from .battery import GetBattery
@@ -8,11 +8,11 @@ from .charge import Charge
 from .charge_state import GetChargeState
 from .clean import Clean, CleanArea, GetCleanInfo
 from .clean_logs import GetCleanLogs
-from .common import CommandWithHandling, SetCommand
+from .common import CommandWithHandling, CommandWithMqttP2PHandling, SetCommand
 from .continuous_cleaning import GetContinuousCleaning, SetContinuousCleaning
 from .error import GetError
 from .fan_speed import FanSpeedLevel, GetFanSpeed, SetFanSpeed
-from .life_span import GetLifeSpan
+from .life_span import GetLifeSpan, ResetLifeSpan
 from .map import (
     GetCachedMapInfo,
     GetMajorMap,
@@ -30,7 +30,7 @@ from .water_info import GetWaterInfo, SetWaterInfo
 
 # fmt: off
 # ordered by file asc
-_COMMANDS: List[Type[CommandWithHandling]] = [
+_COMMANDS: list[type[CommandWithHandling]] = [
     GetAdvancedMode,
     SetAdvancedMode,
 
@@ -58,6 +58,7 @@ _COMMANDS: List[Type[CommandWithHandling]] = [
     SetFanSpeed,
 
     GetLifeSpan,
+    ResetLifeSpan,
 
     GetCachedMapInfo,
     GetMajorMap,
@@ -83,12 +84,12 @@ _COMMANDS: List[Type[CommandWithHandling]] = [
 ]
 # fmt: on
 
-COMMANDS_WITH_HANDLING: Dict[str, Type[CommandWithHandling]] = {
+COMMANDS_WITH_HANDLING: dict[str, type[CommandWithHandling]] = {
     cmd.name: cmd for cmd in _COMMANDS
 }
 
-SET_COMMAND_NAMES: Dict[str, Type[SetCommand]] = {
+COMMANDS_WITH_MQTT_P2P_HANDLING: dict[str, type[CommandWithMqttP2PHandling]] = {
     cmd_name: cmd
     for (cmd_name, cmd) in COMMANDS_WITH_HANDLING.items()
-    if issubclass(cmd, SetCommand)
+    if issubclass(cmd, CommandWithMqttP2PHandling)
 }
